@@ -1,4 +1,4 @@
-/* XDigger  Copyright (C) 1988-98 Alexander Lang.
+/* XDigger  Copyright (C) 1988-99 Alexander Lang.
 
 XDigger is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -1381,19 +1381,22 @@ void RunLevels(int von_level, int bis_level)
 	    case KeyRelease:
 	      keysym = XKeycodeToKeysym(display, event.xkey.keycode, 0);
 
-	      if (keysym == XK_Left)
+	      if (keysym == XK_Left) {
 		if (rd_left) kb_left = False;
 		else rl_left = True;
-	      if (keysym == XK_Right) 
+              }
+	      if (keysym == XK_Right) {
 		if (rd_right) kb_right = False;
 		else rl_right = True;
-	      if (keysym == XK_Up)
+              }
+	      if (keysym == XK_Up) {
 		if (rd_up) kb_up = False;
 		else rl_up = True;
-	      if (keysym == XK_Down)
+              }
+	      if (keysym == XK_Down) {
 		if (rd_down) kb_down = False;
 		else rl_down  = True;
-
+              }
 	      break;
 	    case ClientMessage:
 	      if (event.xclient.data.l[0] == protocol[0])
