@@ -1,4 +1,4 @@
-/* XDigger  Copyright (C) 1988-98 Alexander Lang.
+/* XDigger  Copyright (C) 1988-99 Alexander Lang.
 
 XDigger is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -354,7 +354,7 @@ void Help()
   exit(1);
 } /* Help() */
 
-void main(int argc, char **argv)
+int main(int argc, char **argv)
 {
   int i, m = 0;
   char c;
@@ -485,4 +485,5 @@ void main(int argc, char **argv)
 	}
     }
   all_done(0);
+  return 0;
 } /* main(int argc, char **argv) */
